import sys
import httplib
import traceback
import logging
from logging.handlers import RotatingFileHandler
import os

traceHeaders = ['x-request-id',
                'x-trace-service',
                'x-ot-span-context',
                'x-client-trace-id',
                'x-envoy-force-trace',
                'x-b3-traceid',
                'x-b3-spanid',
                'x-b3-parentspanid',
                'x-b3-sampled',
                'x-b3-flags',
                'testtag1',
                'test-tag2',
                'test_tag3',
                'TEST_TAG']

def sendAndVerify(ip, port, uri, headers):
    print "start to invoke %s" % uri
    logger.info("start to invoke %s" % uri)
    httpClient = None
    try:
        httpClient = httplib.HTTPConnection(ip, port, timeout=30)
        headers["Content-type"] = "application/x-www-form-urlencoded"
        headers["Accept"] = "text/plain"
        httpClient.request("GET", uri, None, headers)
        response = httpClient.getresponse()
        retStatus = response.status
        if retStatus != 200:
            print "Test fail, status code is %s\n" % retStatus
            logger.info("Test fail, status code is %s\n" % retStatus)
            return bool()
        data = response.read()
        print "response data is %s\n" % data
        logger.info("response data is %s\n" % data)
        return bool(1)
    except Exception, e:
        print "Test fail, status exception is %s" % e
        logger.error("Test fail, status exception is %s" % e)
        traceback.print_exc()
        return bool()
    finally:
        if httpClient:
            httpClient.close()

def build_trace_headers(handler):
    retHeaders = {}
    for header in traceHeaders:
        if handler.headers.has_key(header):
            header_value = handler.headers.get(header)
            retHeaders[header] = header_value
    return retHeaders

def set_logger():
    BASE_DIR = os.path.dirname(os.path.abspath(__file__))
    LOG_DIR = os.path.join(BASE_DIR, "logs")
    if not os.path.exists(LOG_DIR):
        os.makedirs(LOG_DIR)
    LOG_FILE = LOG_DIR + "/root.log"
    logger = logging.getLogger("root")
    logger.setLevel(level=logging.INFO)
    # handler = logging.FileHandler(LOG_FILE)
    handler = RotatingFileHandler(LOG_FILE, maxBytes=10*1024, backupCount=10)
    handler.setLevel(logging.INFO)
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)

set_logger()
logger = logging.getLogger("root")

